# This file was created automatically by SWIG.
import misc2c

from windows import *

from misc import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

# Art clients
wxART_TOOLBAR              = 'wxART_TOOLBAR_C'
wxART_MENU                 = 'wxART_MENU_C'
wxART_FRAME_ICON           = 'wxART_FRAME_ICON_C'
wxART_CMN_DIALOG           = 'wxART_CMN_DIALOG_C'
wxART_HELP_BROWSER         = 'wxART_HELP_BROWSER_C'
wxART_MESSAGE_BOX          = 'wxART_MESSAGE_BOX_C'
wxART_OTHER                = 'wxART_OTHER_C'

# Art IDs
wxART_ADD_BOOKMARK         = 'wxART_ADD_BOOKMARK'
wxART_DEL_BOOKMARK         = 'wxART_DEL_BOOKMARK'
wxART_HELP_SIDE_PANEL      = 'wxART_HELP_SIDE_PANEL'
wxART_HELP_SETTINGS        = 'wxART_HELP_SETTINGS'
wxART_HELP_BOOK            = 'wxART_HELP_BOOK'
wxART_HELP_FOLDER          = 'wxART_HELP_FOLDER'
wxART_HELP_PAGE            = 'wxART_HELP_PAGE'
wxART_GO_BACK              = 'wxART_GO_BACK'
wxART_GO_FORWARD           = 'wxART_GO_FORWARD'
wxART_GO_UP                = 'wxART_GO_UP'
wxART_GO_DOWN              = 'wxART_GO_DOWN'
wxART_GO_TO_PARENT         = 'wxART_GO_TO_PARENT'
wxART_GO_HOME              = 'wxART_GO_HOME'
wxART_FILE_OPEN            = 'wxART_FILE_OPEN'
wxART_PRINT                = 'wxART_PRINT'
wxART_HELP                 = 'wxART_HELP'
wxART_TIP                  = 'wxART_TIP'
wxART_REPORT_VIEW          = 'wxART_REPORT_VIEW'
wxART_LIST_VIEW            = 'wxART_LIST_VIEW'
wxART_NEW_DIR              = 'wxART_NEW_DIR'
wxART_FOLDER               = 'wxART_FOLDER'
wxART_GO_DIR_UP            = 'wxART_GO_DIR_UP'
wxART_EXECUTABLE_FILE      = 'wxART_EXECUTABLE_FILE'
wxART_NORMAL_FILE          = 'wxART_NORMAL_FILE'
wxART_TICK_MARK            = 'wxART_TICK_MARK'
wxART_CROSS_MARK           = 'wxART_CROSS_MARK'
wxART_ERROR                = 'wxART_ERROR'
wxART_QUESTION             = 'wxART_QUESTION'
wxART_WARNING              = 'wxART_WARNING'
wxART_INFORMATION          = 'wxART_INFORMATION'

class wxSystemSettingsPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxSystemSettings instance at %s>" % (self.this,)
class wxSystemSettings(wxSystemSettingsPtr):
    def __init__(self,this):
        self.this = this




class wxToolTipPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetTip(self, *_args, **_kwargs):
        val = apply(misc2c.wxToolTip_SetTip,(self,) + _args, _kwargs)
        return val
    def GetTip(self, *_args, **_kwargs):
        val = apply(misc2c.wxToolTip_GetTip,(self,) + _args, _kwargs)
        return val
    def GetWindow(self, *_args, **_kwargs):
        val = apply(misc2c.wxToolTip_GetWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxToolTip instance at %s>" % (self.this,)
class wxToolTip(wxToolTipPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxToolTip,_args,_kwargs)
        self.thisown = 1




class wxCaretPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxCaret):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def IsOk(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_IsOk,(self,) + _args, _kwargs)
        return val
    def IsVisible(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_IsVisible,(self,) + _args, _kwargs)
        return val
    def GetPositionTuple(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_GetPositionTuple,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetSizeTuple(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_GetSizeTuple,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_GetSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetWindow(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_GetWindow,(self,) + _args, _kwargs)
        return val
    def MoveXY(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_MoveXY,(self,) + _args, _kwargs)
        return val
    def Move(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_Move,(self,) + _args, _kwargs)
        return val
    def SetSizeWH(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_SetSizeWH,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_SetSize,(self,) + _args, _kwargs)
        return val
    def Show(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_Show,(self,) + _args, _kwargs)
        return val
    def Hide(self, *_args, **_kwargs):
        val = apply(misc2c.wxCaret_Hide,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxCaret instance at %s>" % (self.this,)
class wxCaret(wxCaretPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxCaret,_args,_kwargs)
        self.thisown = 1




class wxBusyCursorPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxBusyCursor):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def __repr__(self):
        return "<C wxBusyCursor instance at %s>" % (self.this,)
class wxBusyCursor(wxBusyCursorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxBusyCursor,_args,_kwargs)
        self.thisown = 1




class wxWindowDisablerPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxWindowDisabler):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def __repr__(self):
        return "<C wxWindowDisabler instance at %s>" % (self.this,)
class wxWindowDisabler(wxWindowDisablerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxWindowDisabler,_args,_kwargs)
        self.thisown = 1




class wxMutexGuiLockerPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxMutexGuiLocker):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def __repr__(self):
        return "<C wxMutexGuiLocker instance at %s>" % (self.this,)
class wxMutexGuiLocker(wxMutexGuiLockerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxMutexGuiLocker,_args,_kwargs)
        self.thisown = 1




class wxTipProviderPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxTipProvider):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetTip(self, *_args, **_kwargs):
        val = apply(misc2c.wxTipProvider_GetTip,(self,) + _args, _kwargs)
        return val
    def GetCurrentTip(self, *_args, **_kwargs):
        val = apply(misc2c.wxTipProvider_GetCurrentTip,(self,) + _args, _kwargs)
        return val
    def PreprocessTip(self, *_args, **_kwargs):
        val = apply(misc2c.wxTipProvider_PreprocessTip,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTipProvider instance at %s>" % (self.this,)
class wxTipProvider(wxTipProviderPtr):
    def __init__(self,this):
        self.this = this




class wxPyTipProviderPtr(wxTipProviderPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(misc2c.wxPyTipProvider__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyTipProvider instance at %s>" % (self.this,)
class wxPyTipProvider(wxPyTipProviderPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxPyTipProvider,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyTipProvider)




class wxDragImagePtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxDragImage):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetBackingBitmap(self, *_args, **_kwargs):
        val = apply(misc2c.wxDragImage_SetBackingBitmap,(self,) + _args, _kwargs)
        return val
    def BeginDrag(self, *_args, **_kwargs):
        val = apply(misc2c.wxDragImage_BeginDrag,(self,) + _args, _kwargs)
        return val
    def BeginDragBounded(self, *_args, **_kwargs):
        val = apply(misc2c.wxDragImage_BeginDragBounded,(self,) + _args, _kwargs)
        return val
    def EndDrag(self, *_args, **_kwargs):
        val = apply(misc2c.wxDragImage_EndDrag,(self,) + _args, _kwargs)
        return val
    def Move(self, *_args, **_kwargs):
        val = apply(misc2c.wxDragImage_Move,(self,) + _args, _kwargs)
        return val
    def Show(self, *_args, **_kwargs):
        val = apply(misc2c.wxDragImage_Show,(self,) + _args, _kwargs)
        return val
    def Hide(self, *_args, **_kwargs):
        val = apply(misc2c.wxDragImage_Hide,(self,) + _args, _kwargs)
        return val
    def GetImageRect(self, *_args, **_kwargs):
        val = apply(misc2c.wxDragImage_GetImageRect,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def RedrawImage(self, *_args, **_kwargs):
        val = apply(misc2c.wxDragImage_RedrawImage,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDragImage instance at %s>" % (self.this,)
    BeginDrag2 = BeginDragBounded
class wxDragImage(wxDragImagePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxDragImage,_args,_kwargs)
        self.thisown = 1



def wxDragIcon(*_args,**_kwargs):
    val = wxDragImagePtr(apply(misc2c.new_wxDragIcon,_args,_kwargs))
    val.thisown = 1
    return val

def wxDragString(*_args,**_kwargs):
    val = wxDragImagePtr(apply(misc2c.new_wxDragString,_args,_kwargs))
    val.thisown = 1
    return val

def wxDragTreeItem(*_args,**_kwargs):
    val = wxDragImagePtr(apply(misc2c.new_wxDragTreeItem,_args,_kwargs))
    val.thisown = 1
    return val

def wxDragListItem(*_args,**_kwargs):
    val = wxDragImagePtr(apply(misc2c.new_wxDragListItem,_args,_kwargs))
    val.thisown = 1
    return val


class wxPyTimerPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxPyTimer):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetInterval(self, *_args, **_kwargs):
        val = apply(misc2c.wxPyTimer_GetInterval,(self,) + _args, _kwargs)
        return val
    def IsOneShot(self, *_args, **_kwargs):
        val = apply(misc2c.wxPyTimer_IsOneShot,(self,) + _args, _kwargs)
        return val
    def IsRunning(self, *_args, **_kwargs):
        val = apply(misc2c.wxPyTimer_IsRunning,(self,) + _args, _kwargs)
        return val
    def SetOwner(self, *_args, **_kwargs):
        val = apply(misc2c.wxPyTimer_SetOwner,(self,) + _args, _kwargs)
        return val
    def Start(self, *_args, **_kwargs):
        val = apply(misc2c.wxPyTimer_Start,(self,) + _args, _kwargs)
        return val
    def Stop(self, *_args, **_kwargs):
        val = apply(misc2c.wxPyTimer_Stop,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyTimer instance at %s>" % (self.this,)
class wxPyTimer(wxPyTimerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxPyTimer,_args,_kwargs)
        self.thisown = 1




class wxStopWatchPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxStopWatch):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Start(self, *_args, **_kwargs):
        val = apply(misc2c.wxStopWatch_Start,(self,) + _args, _kwargs)
        return val
    def Pause(self, *_args, **_kwargs):
        val = apply(misc2c.wxStopWatch_Pause,(self,) + _args, _kwargs)
        return val
    def Resume(self, *_args, **_kwargs):
        val = apply(misc2c.wxStopWatch_Resume,(self,) + _args, _kwargs)
        return val
    def Time(self, *_args, **_kwargs):
        val = apply(misc2c.wxStopWatch_Time,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxStopWatch instance at %s>" % (self.this,)
class wxStopWatch(wxStopWatchPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxStopWatch,_args,_kwargs)
        self.thisown = 1




class wxLogPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Flush(self, *_args, **_kwargs):
        val = apply(misc2c.wxLog_Flush,(self,) + _args, _kwargs)
        return val
    def HasPendingMessages(self, *_args, **_kwargs):
        val = apply(misc2c.wxLog_HasPendingMessages,(self,) + _args, _kwargs)
        return val
    def GetVerbose(self, *_args, **_kwargs):
        val = apply(misc2c.wxLog_GetVerbose,(self,) + _args, _kwargs)
        return val
    def TimeStamp(self, *_args, **_kwargs):
        val = apply(misc2c.wxLog_TimeStamp,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxLog instance at %s>" % (self.this,)
class wxLog(wxLogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxLog,_args,_kwargs)
        self.thisown = 1




class wxLogStderrPtr(wxLogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxLogStderr instance at %s>" % (self.this,)
class wxLogStderr(wxLogStderrPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxLogStderr,_args,_kwargs)
        self.thisown = 1




class wxLogTextCtrlPtr(wxLogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxLogTextCtrl instance at %s>" % (self.this,)
class wxLogTextCtrl(wxLogTextCtrlPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxLogTextCtrl,_args,_kwargs)
        self.thisown = 1




class wxLogGuiPtr(wxLogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxLogGui instance at %s>" % (self.this,)
class wxLogGui(wxLogGuiPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxLogGui,_args,_kwargs)
        self.thisown = 1




class wxLogWindowPtr(wxLogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Show(self, *_args, **_kwargs):
        val = apply(misc2c.wxLogWindow_Show,(self,) + _args, _kwargs)
        return val
    def GetFrame(self, *_args, **_kwargs):
        val = apply(misc2c.wxLogWindow_GetFrame,(self,) + _args, _kwargs)
        return val
    def GetOldLog(self, *_args, **_kwargs):
        val = apply(misc2c.wxLogWindow_GetOldLog,(self,) + _args, _kwargs)
        if val: val = wxLogPtr(val) 
        return val
    def IsPassingMessages(self, *_args, **_kwargs):
        val = apply(misc2c.wxLogWindow_IsPassingMessages,(self,) + _args, _kwargs)
        return val
    def PassMessages(self, *_args, **_kwargs):
        val = apply(misc2c.wxLogWindow_PassMessages,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxLogWindow instance at %s>" % (self.this,)
class wxLogWindow(wxLogWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxLogWindow,_args,_kwargs)
        self.thisown = 1




class wxLogChainPtr(wxLogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetLog(self, *_args, **_kwargs):
        val = apply(misc2c.wxLogChain_SetLog,(self,) + _args, _kwargs)
        return val
    def PassMessages(self, *_args, **_kwargs):
        val = apply(misc2c.wxLogChain_PassMessages,(self,) + _args, _kwargs)
        return val
    def IsPassingMessages(self, *_args, **_kwargs):
        val = apply(misc2c.wxLogChain_IsPassingMessages,(self,) + _args, _kwargs)
        return val
    def GetOldLog(self, *_args, **_kwargs):
        val = apply(misc2c.wxLogChain_GetOldLog,(self,) + _args, _kwargs)
        if val: val = wxLogPtr(val) 
        return val
    def __repr__(self):
        return "<C wxLogChain instance at %s>" % (self.this,)
class wxLogChain(wxLogChainPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxLogChain,_args,_kwargs)
        self.thisown = 1




class wxLogNullPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxLogNull):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def __repr__(self):
        return "<C wxLogNull instance at %s>" % (self.this,)
class wxLogNull(wxLogNullPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxLogNull,_args,_kwargs)
        self.thisown = 1




class wxPyLogPtr(wxLogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(misc2c.wxPyLog__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def Destroy(self, *_args, **_kwargs):
        val = apply(misc2c.wxPyLog_Destroy,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyLog instance at %s>" % (self.this,)
class wxPyLog(wxPyLogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxPyLog,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyLog)




class wxProcessEventPtr(wxEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPid(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcessEvent_GetPid,(self,) + _args, _kwargs)
        return val
    def GetExitCode(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcessEvent_GetExitCode,(self,) + _args, _kwargs)
        return val
    def __setattr__(self,name,value):
        if name == "m_pid" :
            misc2c.wxProcessEvent_m_pid_set(self,value)
            return
        if name == "m_exitcode" :
            misc2c.wxProcessEvent_m_exitcode_set(self,value)
            return
        self.__dict__[name] = value
    def __getattr__(self,name):
        if name == "m_pid" : 
            return misc2c.wxProcessEvent_m_pid_get(self)
        if name == "m_exitcode" : 
            return misc2c.wxProcessEvent_m_exitcode_get(self)
        raise AttributeError,name
    def __repr__(self):
        return "<C wxProcessEvent instance at %s>" % (self.this,)
class wxProcessEvent(wxProcessEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxProcessEvent,_args,_kwargs)
        self.thisown = 1




class wxProcessPtr(wxEvtHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Destroy(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_Destroy,(self,) + _args, _kwargs)
        return val
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_OnTerminate(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_base_OnTerminate,(self,) + _args, _kwargs)
        return val
    def Redirect(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_Redirect,(self,) + _args, _kwargs)
        return val
    def IsRedirected(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_IsRedirected,(self,) + _args, _kwargs)
        return val
    def Detach(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_Detach,(self,) + _args, _kwargs)
        return val
    def GetInputStream(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_GetInputStream,(self,) + _args, _kwargs)
        return val
    def GetErrorStream(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_GetErrorStream,(self,) + _args, _kwargs)
        return val
    def GetOutputStream(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_GetOutputStream,(self,) + _args, _kwargs)
        if val: val = wxOutputStreamPtr(val) 
        return val
    def CloseOutput(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_CloseOutput,(self,) + _args, _kwargs)
        return val
    def IsInputOpened(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_IsInputOpened,(self,) + _args, _kwargs)
        return val
    def IsInputAvailable(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_IsInputAvailable,(self,) + _args, _kwargs)
        return val
    def IsErrorAvailable(self, *_args, **_kwargs):
        val = apply(misc2c.wxProcess_IsErrorAvailable,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxProcess instance at %s>" % (self.this,)
class wxProcess(wxProcessPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxProcess,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxProcess)




class wxJoystickPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxJoystick):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetPosition(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetZPosition(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetZPosition,(self,) + _args, _kwargs)
        return val
    def GetButtonState(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetButtonState,(self,) + _args, _kwargs)
        return val
    def GetPOVPosition(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetPOVPosition,(self,) + _args, _kwargs)
        return val
    def GetPOVCTSPosition(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetPOVCTSPosition,(self,) + _args, _kwargs)
        return val
    def GetRudderPosition(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetRudderPosition,(self,) + _args, _kwargs)
        return val
    def GetUPosition(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetUPosition,(self,) + _args, _kwargs)
        return val
    def GetVPosition(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetVPosition,(self,) + _args, _kwargs)
        return val
    def GetMovementThreshold(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetMovementThreshold,(self,) + _args, _kwargs)
        return val
    def SetMovementThreshold(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_SetMovementThreshold,(self,) + _args, _kwargs)
        return val
    def IsOk(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_IsOk,(self,) + _args, _kwargs)
        return val
    def GetNumberJoysticks(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetNumberJoysticks,(self,) + _args, _kwargs)
        return val
    def GetManufacturerId(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetManufacturerId,(self,) + _args, _kwargs)
        return val
    def GetProductId(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetProductId,(self,) + _args, _kwargs)
        return val
    def GetProductName(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetProductName,(self,) + _args, _kwargs)
        return val
    def GetXMin(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetXMin,(self,) + _args, _kwargs)
        return val
    def GetYMin(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetYMin,(self,) + _args, _kwargs)
        return val
    def GetZMin(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetZMin,(self,) + _args, _kwargs)
        return val
    def GetXMax(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetXMax,(self,) + _args, _kwargs)
        return val
    def GetYMax(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetYMax,(self,) + _args, _kwargs)
        return val
    def GetZMax(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetZMax,(self,) + _args, _kwargs)
        return val
    def GetNumberButtons(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetNumberButtons,(self,) + _args, _kwargs)
        return val
    def GetNumberAxes(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetNumberAxes,(self,) + _args, _kwargs)
        return val
    def GetMaxButtons(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetMaxButtons,(self,) + _args, _kwargs)
        return val
    def GetMaxAxes(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetMaxAxes,(self,) + _args, _kwargs)
        return val
    def GetPollingMin(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetPollingMin,(self,) + _args, _kwargs)
        return val
    def GetPollingMax(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetPollingMax,(self,) + _args, _kwargs)
        return val
    def GetRudderMin(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetRudderMin,(self,) + _args, _kwargs)
        return val
    def GetRudderMax(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetRudderMax,(self,) + _args, _kwargs)
        return val
    def GetUMin(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetUMin,(self,) + _args, _kwargs)
        return val
    def GetUMax(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetUMax,(self,) + _args, _kwargs)
        return val
    def GetVMin(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetVMin,(self,) + _args, _kwargs)
        return val
    def GetVMax(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_GetVMax,(self,) + _args, _kwargs)
        return val
    def HasRudder(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_HasRudder,(self,) + _args, _kwargs)
        return val
    def HasZ(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_HasZ,(self,) + _args, _kwargs)
        return val
    def HasU(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_HasU,(self,) + _args, _kwargs)
        return val
    def HasV(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_HasV,(self,) + _args, _kwargs)
        return val
    def HasPOV(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_HasPOV,(self,) + _args, _kwargs)
        return val
    def HasPOV4Dir(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_HasPOV4Dir,(self,) + _args, _kwargs)
        return val
    def HasPOVCTS(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_HasPOVCTS,(self,) + _args, _kwargs)
        return val
    def SetCapture(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_SetCapture,(self,) + _args, _kwargs)
        return val
    def ReleaseCapture(self, *_args, **_kwargs):
        val = apply(misc2c.wxJoystick_ReleaseCapture,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxJoystick instance at %s>" % (self.this,)
class wxJoystick(wxJoystickPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxJoystick,_args,_kwargs)
        self.thisown = 1




class wxWavePtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxWave):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def IsOk(self, *_args, **_kwargs):
        val = apply(misc2c.wxWave_IsOk,(self,) + _args, _kwargs)
        return val
    def Play(self, *_args, **_kwargs):
        val = apply(misc2c.wxWave_Play,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxWave instance at %s>" % (self.this,)
class wxWave(wxWavePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxWave,_args,_kwargs)
        self.thisown = 1




class wxFileTypeInfoPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def IsValid(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_IsValid,(self,) + _args, _kwargs)
        return val
    def SetIcon(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_SetIcon,(self,) + _args, _kwargs)
        return val
    def SetShortDesc(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_SetShortDesc,(self,) + _args, _kwargs)
        return val
    def GetMimeType(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_GetMimeType,(self,) + _args, _kwargs)
        return val
    def GetOpenCommand(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_GetOpenCommand,(self,) + _args, _kwargs)
        return val
    def GetPrintCommand(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_GetPrintCommand,(self,) + _args, _kwargs)
        return val
    def GetShortDesc(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_GetShortDesc,(self,) + _args, _kwargs)
        return val
    def GetDescription(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_GetDescription,(self,) + _args, _kwargs)
        return val
    def GetExtensions(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_GetExtensions,(self,) + _args, _kwargs)
        return val
    def GetExtensionsCount(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_GetExtensionsCount,(self,) + _args, _kwargs)
        return val
    def GetIconFile(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_GetIconFile,(self,) + _args, _kwargs)
        return val
    def GetIconIndex(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileTypeInfo_GetIconIndex,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFileTypeInfo instance at %s>" % (self.this,)
class wxFileTypeInfo(wxFileTypeInfoPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxFileTypeInfo,_args,_kwargs)
        self.thisown = 1



def wxFileTypeInfoSequence(*_args,**_kwargs):
    val = wxFileTypeInfoPtr(apply(misc2c.new_wxFileTypeInfoSequence,_args,_kwargs))
    val.thisown = 1
    return val

def wxNullFileTypeInfo(*_args,**_kwargs):
    val = wxFileTypeInfoPtr(apply(misc2c.new_wxNullFileTypeInfo,_args,_kwargs))
    val.thisown = 1
    return val


class wxFileTypePtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetMimeType(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_GetMimeType,(self,) + _args, _kwargs)
        return val
    def GetMimeTypes(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_GetMimeTypes,(self,) + _args, _kwargs)
        return val
    def GetExtensions(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_GetExtensions,(self,) + _args, _kwargs)
        return val
    def GetIcon(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_GetIcon,(self,) + _args, _kwargs)
        if val: val = wxIconPtr(val) ; val.thisown = 1
        return val
    def GetIconInfo(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_GetIconInfo,(self,) + _args, _kwargs)
        return val
    def GetDescription(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_GetDescription,(self,) + _args, _kwargs)
        return val
    def GetOpenCommand(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_GetOpenCommand,(self,) + _args, _kwargs)
        return val
    def GetPrintCommand(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_GetPrintCommand,(self,) + _args, _kwargs)
        return val
    def GetAllCommands(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_GetAllCommands,(self,) + _args, _kwargs)
        return val
    def SetCommand(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_SetCommand,(self,) + _args, _kwargs)
        return val
    def SetDefaultIcon(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_SetDefaultIcon,(self,) + _args, _kwargs)
        return val
    def Unassociate(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileType_Unassociate,(self,) + _args, _kwargs)
        return val
    def __del__(self, delfunc=misc2c.delete_wxFileType):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def __repr__(self):
        return "<C wxFileType instance at %s>" % (self.this,)
class wxFileType(wxFileTypePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxFileType,_args,_kwargs)
        self.thisown = 1




class wxMimeTypesManagerPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Initialize(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_Initialize,(self,) + _args, _kwargs)
        return val
    def ClearData(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_ClearData,(self,) + _args, _kwargs)
        return val
    def GetFileTypeFromExtension(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_GetFileTypeFromExtension,(self,) + _args, _kwargs)
        if val: val = wxFileTypePtr(val) ; val.thisown = 1
        return val
    def GetFileTypeFromMimeType(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_GetFileTypeFromMimeType,(self,) + _args, _kwargs)
        if val: val = wxFileTypePtr(val) ; val.thisown = 1
        return val
    def ReadMailcap(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_ReadMailcap,(self,) + _args, _kwargs)
        return val
    def ReadMimeTypes(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_ReadMimeTypes,(self,) + _args, _kwargs)
        return val
    def EnumAllFileTypes(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_EnumAllFileTypes,(self,) + _args, _kwargs)
        return val
    def AddFallback(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_AddFallback,(self,) + _args, _kwargs)
        return val
    def Associate(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_Associate,(self,) + _args, _kwargs)
        if val: val = wxFileTypePtr(val) ; val.thisown = 1
        return val
    def Unassociate(self, *_args, **_kwargs):
        val = apply(misc2c.wxMimeTypesManager_Unassociate,(self,) + _args, _kwargs)
        return val
    def __del__(self, delfunc=misc2c.delete_wxMimeTypesManager):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def __repr__(self):
        return "<C wxMimeTypesManager instance at %s>" % (self.this,)
class wxMimeTypesManager(wxMimeTypesManagerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxMimeTypesManager,_args,_kwargs)
        self.thisown = 1




class wxArtProviderPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(misc2c.wxArtProvider__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxArtProvider instance at %s>" % (self.this,)
class wxArtProvider(wxArtProviderPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxArtProvider,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxArtProvider)




class wxFileHistoryPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxFileHistory):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def AddFileToHistory(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_AddFileToHistory,(self,) + _args, _kwargs)
        return val
    def RemoveFileFromHistory(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_RemoveFileFromHistory,(self,) + _args, _kwargs)
        return val
    def GetMaxFiles(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_GetMaxFiles,(self,) + _args, _kwargs)
        return val
    def UseMenu(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_UseMenu,(self,) + _args, _kwargs)
        return val
    def RemoveMenu(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_RemoveMenu,(self,) + _args, _kwargs)
        return val
    def Load(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_Load,(self,) + _args, _kwargs)
        return val
    def Save(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_Save,(self,) + _args, _kwargs)
        return val
    def AddFilesToMenu(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_AddFilesToMenu,(self,) + _args, _kwargs)
        return val
    def AddFilesToThisMenu(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_AddFilesToThisMenu,(self,) + _args, _kwargs)
        return val
    def GetHistoryFile(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_GetHistoryFile,(self,) + _args, _kwargs)
        return val
    def GetCount(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_GetCount,(self,) + _args, _kwargs)
        return val
    def GetNoHistoryFiles(self, *_args, **_kwargs):
        val = apply(misc2c.wxFileHistory_GetNoHistoryFiles,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFileHistory instance at %s>" % (self.this,)
class wxFileHistory(wxFileHistoryPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxFileHistory,_args,_kwargs)
        self.thisown = 1




class wxEffectsPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetHighlightColour(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_GetHighlightColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetLightShadow(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_GetLightShadow,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetFaceColour(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_GetFaceColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetMediumShadow(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_GetMediumShadow,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetDarkShadow(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_GetDarkShadow,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def SetHighlightColour(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_SetHighlightColour,(self,) + _args, _kwargs)
        return val
    def SetLightShadow(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_SetLightShadow,(self,) + _args, _kwargs)
        return val
    def SetFaceColour(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_SetFaceColour,(self,) + _args, _kwargs)
        return val
    def SetMediumShadow(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_SetMediumShadow,(self,) + _args, _kwargs)
        return val
    def SetDarkShadow(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_SetDarkShadow,(self,) + _args, _kwargs)
        return val
    def Set(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_Set,(self,) + _args, _kwargs)
        return val
    def DrawSunkenEdge(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_DrawSunkenEdge,(self,) + _args, _kwargs)
        return val
    def TileBitmap(self, *_args, **_kwargs):
        val = apply(misc2c.wxEffects_TileBitmap,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxEffects instance at %s>" % (self.this,)
class wxEffects(wxEffectsPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxEffects,_args,_kwargs)
        self.thisown = 1




class wxSingleInstanceCheckerPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=misc2c.delete_wxSingleInstanceChecker):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Create(self, *_args, **_kwargs):
        val = apply(misc2c.wxSingleInstanceChecker_Create,(self,) + _args, _kwargs)
        return val
    def IsAnotherRunning(self, *_args, **_kwargs):
        val = apply(misc2c.wxSingleInstanceChecker_IsAnotherRunning,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSingleInstanceChecker instance at %s>" % (self.this,)
class wxSingleInstanceChecker(wxSingleInstanceCheckerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(misc2c.new_wxSingleInstanceChecker,_args,_kwargs)
        self.thisown = 1



def wxPreSingleInstanceChecker(*_args,**_kwargs):
    val = wxSingleInstanceCheckerPtr(apply(misc2c.new_wxPreSingleInstanceChecker,_args,_kwargs))
    val.thisown = 1
    return val




#-------------- FUNCTION WRAPPERS ------------------

wxFileSelector = misc2c.wxFileSelector

wxLoadFileSelector = misc2c.wxLoadFileSelector

wxSaveFileSelector = misc2c.wxSaveFileSelector

wxDirSelector = misc2c.wxDirSelector

wxGetTextFromUser = misc2c.wxGetTextFromUser

wxGetPasswordFromUser = misc2c.wxGetPasswordFromUser

wxGetSingleChoice = misc2c.wxGetSingleChoice

wxGetSingleChoiceIndex = misc2c.wxGetSingleChoiceIndex

wxMessageBox = misc2c.wxMessageBox

wxGetNumberFromUser = misc2c.wxGetNumberFromUser

wxColourDisplay = misc2c.wxColourDisplay

wxDisplayDepth = misc2c.wxDisplayDepth

wxGetDisplayDepth = misc2c.wxGetDisplayDepth

wxDisplaySize = misc2c.wxDisplaySize

def wxGetDisplaySize(*_args, **_kwargs):
    val = apply(misc2c.wxGetDisplaySize,_args,_kwargs)
    if val: val = wxSizePtr(val); val.thisown = 1
    return val

wxDisplaySizeMM = misc2c.wxDisplaySizeMM

def wxGetDisplaySizeMM(*_args, **_kwargs):
    val = apply(misc2c.wxGetDisplaySizeMM,_args,_kwargs)
    if val: val = wxSizePtr(val); val.thisown = 1
    return val

wxClientDisplayRect = misc2c.wxClientDisplayRect

def wxGetClientDisplayRect(*_args, **_kwargs):
    val = apply(misc2c.wxGetClientDisplayRect,_args,_kwargs)
    if val: val = wxRectPtr(val); val.thisown = 1
    return val

wxSetCursor = misc2c.wxSetCursor

wxBeginBusyCursor = misc2c.wxBeginBusyCursor

def wxGetActiveWindow(*_args, **_kwargs):
    val = apply(misc2c.wxGetActiveWindow,_args,_kwargs)
    return val

def wxGenericFindWindowAtPoint(*_args, **_kwargs):
    val = apply(misc2c.wxGenericFindWindowAtPoint,_args,_kwargs)
    return val

def wxFindWindowAtPoint(*_args, **_kwargs):
    val = apply(misc2c.wxFindWindowAtPoint,_args,_kwargs)
    return val

def wxGetTopLevelParent(*_args, **_kwargs):
    val = apply(misc2c.wxGetTopLevelParent,_args,_kwargs)
    return val

wxCaret_GetBlinkTime = misc2c.wxCaret_GetBlinkTime

wxCaret_SetBlinkTime = misc2c.wxCaret_SetBlinkTime

wxSafeYield = misc2c.wxSafeYield

wxPostEvent = misc2c.wxPostEvent

wxWakeUpIdle = misc2c.wxWakeUpIdle

wxMutexGuiEnter = misc2c.wxMutexGuiEnter

wxMutexGuiLeave = misc2c.wxMutexGuiLeave

wxThread_IsMain = misc2c.wxThread_IsMain

wxShowTip = misc2c.wxShowTip

def wxCreateFileTipProvider(*_args, **_kwargs):
    val = apply(misc2c.wxCreateFileTipProvider,_args,_kwargs)
    if val: val = wxTipProviderPtr(val); val.thisown = 1
    return val

wxSysErrorCode = misc2c.wxSysErrorCode

wxSysErrorMsg = misc2c.wxSysErrorMsg

wxLogFatalError = misc2c.wxLogFatalError

wxLogError = misc2c.wxLogError

wxLogWarning = misc2c.wxLogWarning

wxLogMessage = misc2c.wxLogMessage

wxLogInfo = misc2c.wxLogInfo

wxLogDebug = misc2c.wxLogDebug

wxLogVerbose = misc2c.wxLogVerbose

wxLogStatus = misc2c.wxLogStatus

wxLogStatusFrame = misc2c.wxLogStatusFrame

wxLogSysError = misc2c.wxLogSysError

wxLogTrace = misc2c.wxLogTrace

wxLogTraceMask = misc2c.wxLogTraceMask

wxLogGeneric = misc2c.wxLogGeneric

wxSafeShowMessage = misc2c.wxSafeShowMessage

wxExecute = misc2c.wxExecute

def wxWaveData(*_args, **_kwargs):
    val = apply(misc2c.wxWaveData,_args,_kwargs)
    if val: val = wxWavePtr(val); val.thisown = 1
    return val

def wxSystemSettings_GetColour(*_args, **_kwargs):
    val = apply(misc2c.wxSystemSettings_GetColour,_args,_kwargs)
    if val: val = wxColourPtr(val); val.thisown = 1
    return val

def wxSystemSettings_GetFont(*_args, **_kwargs):
    val = apply(misc2c.wxSystemSettings_GetFont,_args,_kwargs)
    if val: val = wxFontPtr(val); val.thisown = 1
    return val

wxSystemSettings_GetMetric = misc2c.wxSystemSettings_GetMetric

wxSystemSettings_HasFeature = misc2c.wxSystemSettings_HasFeature

wxSystemSettings_GetScreenType = misc2c.wxSystemSettings_GetScreenType

wxSystemSettings_SetScreenType = misc2c.wxSystemSettings_SetScreenType

wxToolTip_Enable = misc2c.wxToolTip_Enable

wxToolTip_SetDelay = misc2c.wxToolTip_SetDelay

wxLog_IsEnabled = misc2c.wxLog_IsEnabled

wxLog_EnableLogging = misc2c.wxLog_EnableLogging

wxLog_OnLog = misc2c.wxLog_OnLog

wxLog_FlushActive = misc2c.wxLog_FlushActive

def wxLog_GetActiveTarget(*_args, **_kwargs):
    val = apply(misc2c.wxLog_GetActiveTarget,_args,_kwargs)
    if val: val = wxLogPtr(val)
    return val

def wxLog_SetActiveTarget(*_args, **_kwargs):
    val = apply(misc2c.wxLog_SetActiveTarget,_args,_kwargs)
    if val: val = wxLogPtr(val)
    return val

wxLog_Suspend = misc2c.wxLog_Suspend

wxLog_Resume = misc2c.wxLog_Resume

wxLog_SetVerbose = misc2c.wxLog_SetVerbose

wxLog_DontCreateOnDemand = misc2c.wxLog_DontCreateOnDemand

wxLog_SetTraceMask = misc2c.wxLog_SetTraceMask

wxLog_AddTraceMask = misc2c.wxLog_AddTraceMask

wxLog_RemoveTraceMask = misc2c.wxLog_RemoveTraceMask

wxLog_ClearTraceMasks = misc2c.wxLog_ClearTraceMasks

wxLog_GetTraceMasks = misc2c.wxLog_GetTraceMasks

wxLog_SetTimestamp = misc2c.wxLog_SetTimestamp

wxLog_GetTimestamp = misc2c.wxLog_GetTimestamp

wxLog_GetTraceMask = misc2c.wxLog_GetTraceMask

wxLog_IsAllowedTraceMask = misc2c.wxLog_IsAllowedTraceMask

wxLog_SetLogLevel = misc2c.wxLog_SetLogLevel

wxLog_GetLogLevel = misc2c.wxLog_GetLogLevel

wxProcess_Kill = misc2c.wxProcess_Kill

wxProcess_Exists = misc2c.wxProcess_Exists

def wxProcess_Open(*_args, **_kwargs):
    val = apply(misc2c.wxProcess_Open,_args,_kwargs)
    if val: val = wxProcessPtr(val)
    return val

wxFileType_ExpandCommand = misc2c.wxFileType_ExpandCommand

wxMimeTypesManager_IsOfType = misc2c.wxMimeTypesManager_IsOfType

wxArtProvider_PushProvider = misc2c.wxArtProvider_PushProvider

wxArtProvider_PopProvider = misc2c.wxArtProvider_PopProvider

wxArtProvider_RemoveProvider = misc2c.wxArtProvider_RemoveProvider

def wxArtProvider_GetBitmap(*_args, **_kwargs):
    val = apply(misc2c.wxArtProvider_GetBitmap,_args,_kwargs)
    if val: val = wxBitmapPtr(val); val.thisown = 1
    return val

def wxArtProvider_GetIcon(*_args, **_kwargs):
    val = apply(misc2c.wxArtProvider_GetIcon,_args,_kwargs)
    if val: val = wxIconPtr(val); val.thisown = 1
    return val



#-------------- VARIABLE WRAPPERS ------------------

wxSYS_OEM_FIXED_FONT = misc2c.wxSYS_OEM_FIXED_FONT
wxSYS_ANSI_FIXED_FONT = misc2c.wxSYS_ANSI_FIXED_FONT
wxSYS_ANSI_VAR_FONT = misc2c.wxSYS_ANSI_VAR_FONT
wxSYS_SYSTEM_FONT = misc2c.wxSYS_SYSTEM_FONT
wxSYS_DEVICE_DEFAULT_FONT = misc2c.wxSYS_DEVICE_DEFAULT_FONT
wxSYS_DEFAULT_PALETTE = misc2c.wxSYS_DEFAULT_PALETTE
wxSYS_SYSTEM_FIXED_FONT = misc2c.wxSYS_SYSTEM_FIXED_FONT
wxSYS_DEFAULT_GUI_FONT = misc2c.wxSYS_DEFAULT_GUI_FONT
wxSYS_COLOUR_SCROLLBAR = misc2c.wxSYS_COLOUR_SCROLLBAR
wxSYS_COLOUR_BACKGROUND = misc2c.wxSYS_COLOUR_BACKGROUND
wxSYS_COLOUR_DESKTOP = misc2c.wxSYS_COLOUR_DESKTOP
wxSYS_COLOUR_ACTIVECAPTION = misc2c.wxSYS_COLOUR_ACTIVECAPTION
wxSYS_COLOUR_INACTIVECAPTION = misc2c.wxSYS_COLOUR_INACTIVECAPTION
wxSYS_COLOUR_MENU = misc2c.wxSYS_COLOUR_MENU
wxSYS_COLOUR_WINDOW = misc2c.wxSYS_COLOUR_WINDOW
wxSYS_COLOUR_WINDOWFRAME = misc2c.wxSYS_COLOUR_WINDOWFRAME
wxSYS_COLOUR_MENUTEXT = misc2c.wxSYS_COLOUR_MENUTEXT
wxSYS_COLOUR_WINDOWTEXT = misc2c.wxSYS_COLOUR_WINDOWTEXT
wxSYS_COLOUR_CAPTIONTEXT = misc2c.wxSYS_COLOUR_CAPTIONTEXT
wxSYS_COLOUR_ACTIVEBORDER = misc2c.wxSYS_COLOUR_ACTIVEBORDER
wxSYS_COLOUR_INACTIVEBORDER = misc2c.wxSYS_COLOUR_INACTIVEBORDER
wxSYS_COLOUR_APPWORKSPACE = misc2c.wxSYS_COLOUR_APPWORKSPACE
wxSYS_COLOUR_HIGHLIGHT = misc2c.wxSYS_COLOUR_HIGHLIGHT
wxSYS_COLOUR_HIGHLIGHTTEXT = misc2c.wxSYS_COLOUR_HIGHLIGHTTEXT
wxSYS_COLOUR_BTNFACE = misc2c.wxSYS_COLOUR_BTNFACE
wxSYS_COLOUR_3DFACE = misc2c.wxSYS_COLOUR_3DFACE
wxSYS_COLOUR_BTNSHADOW = misc2c.wxSYS_COLOUR_BTNSHADOW
wxSYS_COLOUR_3DSHADOW = misc2c.wxSYS_COLOUR_3DSHADOW
wxSYS_COLOUR_GRAYTEXT = misc2c.wxSYS_COLOUR_GRAYTEXT
wxSYS_COLOUR_BTNTEXT = misc2c.wxSYS_COLOUR_BTNTEXT
wxSYS_COLOUR_INACTIVECAPTIONTEXT = misc2c.wxSYS_COLOUR_INACTIVECAPTIONTEXT
wxSYS_COLOUR_BTNHIGHLIGHT = misc2c.wxSYS_COLOUR_BTNHIGHLIGHT
wxSYS_COLOUR_BTNHILIGHT = misc2c.wxSYS_COLOUR_BTNHILIGHT
wxSYS_COLOUR_3DHIGHLIGHT = misc2c.wxSYS_COLOUR_3DHIGHLIGHT
wxSYS_COLOUR_3DHILIGHT = misc2c.wxSYS_COLOUR_3DHILIGHT
wxSYS_COLOUR_3DDKSHADOW = misc2c.wxSYS_COLOUR_3DDKSHADOW
wxSYS_COLOUR_3DLIGHT = misc2c.wxSYS_COLOUR_3DLIGHT
wxSYS_COLOUR_INFOTEXT = misc2c.wxSYS_COLOUR_INFOTEXT
wxSYS_COLOUR_INFOBK = misc2c.wxSYS_COLOUR_INFOBK
wxSYS_COLOUR_LISTBOX = misc2c.wxSYS_COLOUR_LISTBOX
wxSYS_COLOUR_HOTLIGHT = misc2c.wxSYS_COLOUR_HOTLIGHT
wxSYS_COLOUR_GRADIENTACTIVECAPTION = misc2c.wxSYS_COLOUR_GRADIENTACTIVECAPTION
wxSYS_COLOUR_GRADIENTINACTIVECAPTION = misc2c.wxSYS_COLOUR_GRADIENTINACTIVECAPTION
wxSYS_COLOUR_MENUHILIGHT = misc2c.wxSYS_COLOUR_MENUHILIGHT
wxSYS_COLOUR_MENUBAR = misc2c.wxSYS_COLOUR_MENUBAR
wxSYS_COLOUR_MAX = misc2c.wxSYS_COLOUR_MAX
wxSYS_MOUSE_BUTTONS = misc2c.wxSYS_MOUSE_BUTTONS
wxSYS_BORDER_X = misc2c.wxSYS_BORDER_X
wxSYS_BORDER_Y = misc2c.wxSYS_BORDER_Y
wxSYS_CURSOR_X = misc2c.wxSYS_CURSOR_X
wxSYS_CURSOR_Y = misc2c.wxSYS_CURSOR_Y
wxSYS_DCLICK_X = misc2c.wxSYS_DCLICK_X
wxSYS_DCLICK_Y = misc2c.wxSYS_DCLICK_Y
wxSYS_DRAG_X = misc2c.wxSYS_DRAG_X
wxSYS_DRAG_Y = misc2c.wxSYS_DRAG_Y
wxSYS_EDGE_X = misc2c.wxSYS_EDGE_X
wxSYS_EDGE_Y = misc2c.wxSYS_EDGE_Y
wxSYS_HSCROLL_ARROW_X = misc2c.wxSYS_HSCROLL_ARROW_X
wxSYS_HSCROLL_ARROW_Y = misc2c.wxSYS_HSCROLL_ARROW_Y
wxSYS_HTHUMB_X = misc2c.wxSYS_HTHUMB_X
wxSYS_ICON_X = misc2c.wxSYS_ICON_X
wxSYS_ICON_Y = misc2c.wxSYS_ICON_Y
wxSYS_ICONSPACING_X = misc2c.wxSYS_ICONSPACING_X
wxSYS_ICONSPACING_Y = misc2c.wxSYS_ICONSPACING_Y
wxSYS_WINDOWMIN_X = misc2c.wxSYS_WINDOWMIN_X
wxSYS_WINDOWMIN_Y = misc2c.wxSYS_WINDOWMIN_Y
wxSYS_SCREEN_X = misc2c.wxSYS_SCREEN_X
wxSYS_SCREEN_Y = misc2c.wxSYS_SCREEN_Y
wxSYS_FRAMESIZE_X = misc2c.wxSYS_FRAMESIZE_X
wxSYS_FRAMESIZE_Y = misc2c.wxSYS_FRAMESIZE_Y
wxSYS_SMALLICON_X = misc2c.wxSYS_SMALLICON_X
wxSYS_SMALLICON_Y = misc2c.wxSYS_SMALLICON_Y
wxSYS_HSCROLL_Y = misc2c.wxSYS_HSCROLL_Y
wxSYS_VSCROLL_X = misc2c.wxSYS_VSCROLL_X
wxSYS_VSCROLL_ARROW_X = misc2c.wxSYS_VSCROLL_ARROW_X
wxSYS_VSCROLL_ARROW_Y = misc2c.wxSYS_VSCROLL_ARROW_Y
wxSYS_VTHUMB_Y = misc2c.wxSYS_VTHUMB_Y
wxSYS_CAPTION_Y = misc2c.wxSYS_CAPTION_Y
wxSYS_MENU_Y = misc2c.wxSYS_MENU_Y
wxSYS_NETWORK_PRESENT = misc2c.wxSYS_NETWORK_PRESENT
wxSYS_PENWINDOWS_PRESENT = misc2c.wxSYS_PENWINDOWS_PRESENT
wxSYS_SHOW_SOUNDS = misc2c.wxSYS_SHOW_SOUNDS
wxSYS_SWAP_BUTTONS = misc2c.wxSYS_SWAP_BUTTONS
wxSYS_CAN_DRAW_FRAME_DECORATIONS = misc2c.wxSYS_CAN_DRAW_FRAME_DECORATIONS
wxSYS_CAN_ICONIZE_FRAME = misc2c.wxSYS_CAN_ICONIZE_FRAME
wxSYS_SCREEN_NONE = misc2c.wxSYS_SCREEN_NONE
wxSYS_SCREEN_TINY = misc2c.wxSYS_SCREEN_TINY
wxSYS_SCREEN_PDA = misc2c.wxSYS_SCREEN_PDA
wxSYS_SCREEN_SMALL = misc2c.wxSYS_SCREEN_SMALL
wxSYS_SCREEN_DESKTOP = misc2c.wxSYS_SCREEN_DESKTOP
wxLOG_FatalError = misc2c.wxLOG_FatalError
wxLOG_Error = misc2c.wxLOG_Error
wxLOG_Warning = misc2c.wxLOG_Warning
wxLOG_Message = misc2c.wxLOG_Message
wxLOG_Info = misc2c.wxLOG_Info
wxLOG_Status = misc2c.wxLOG_Status
wxLOG_Debug = misc2c.wxLOG_Debug
wxLOG_Trace = misc2c.wxLOG_Trace
wxLOG_Progress = misc2c.wxLOG_Progress
wxLOG_User = misc2c.wxLOG_User
wxTRACE_MemAlloc = misc2c.wxTRACE_MemAlloc
wxTRACE_Messages = misc2c.wxTRACE_Messages
wxTRACE_ResAlloc = misc2c.wxTRACE_ResAlloc
wxTRACE_RefCount = misc2c.wxTRACE_RefCount
wxTraceMemAlloc = misc2c.wxTraceMemAlloc
wxTraceMessages = misc2c.wxTraceMessages
wxTraceResAlloc = misc2c.wxTraceResAlloc
wxTraceRefCount = misc2c.wxTraceRefCount
wxKILL_OK = misc2c.wxKILL_OK
wxKILL_BAD_SIGNAL = misc2c.wxKILL_BAD_SIGNAL
wxKILL_ACCESS_DENIED = misc2c.wxKILL_ACCESS_DENIED
wxKILL_NO_PROCESS = misc2c.wxKILL_NO_PROCESS
wxKILL_ERROR = misc2c.wxKILL_ERROR
wxSIGNONE = misc2c.wxSIGNONE
wxSIGHUP = misc2c.wxSIGHUP
wxSIGINT = misc2c.wxSIGINT
wxSIGQUIT = misc2c.wxSIGQUIT
wxSIGILL = misc2c.wxSIGILL
wxSIGTRAP = misc2c.wxSIGTRAP
wxSIGABRT = misc2c.wxSIGABRT
wxSIGIOT = misc2c.wxSIGIOT
wxSIGEMT = misc2c.wxSIGEMT
wxSIGFPE = misc2c.wxSIGFPE
wxSIGKILL = misc2c.wxSIGKILL
wxSIGBUS = misc2c.wxSIGBUS
wxSIGSEGV = misc2c.wxSIGSEGV
wxSIGSYS = misc2c.wxSIGSYS
wxSIGPIPE = misc2c.wxSIGPIPE
wxSIGALRM = misc2c.wxSIGALRM
wxSIGTERM = misc2c.wxSIGTERM
wxEVT_END_PROCESS = misc2c.wxEVT_END_PROCESS
wxEXEC_ASYNC = misc2c.wxEXEC_ASYNC
wxEXEC_SYNC = misc2c.wxEXEC_SYNC
wxEXEC_NOHIDE = misc2c.wxEXEC_NOHIDE
wxEXEC_MAKE_GROUP_LEADER = misc2c.wxEXEC_MAKE_GROUP_LEADER
wxJOYSTICK1 = misc2c.wxJOYSTICK1
wxJOYSTICK2 = misc2c.wxJOYSTICK2
wxJOY_BUTTON_ANY = misc2c.wxJOY_BUTTON_ANY
wxJOY_BUTTON1 = misc2c.wxJOY_BUTTON1
wxJOY_BUTTON2 = misc2c.wxJOY_BUTTON2
wxJOY_BUTTON3 = misc2c.wxJOY_BUTTON3
wxJOY_BUTTON4 = misc2c.wxJOY_BUTTON4
wxMAILCAP_STANDARD = misc2c.wxMAILCAP_STANDARD
wxMAILCAP_NETSCAPE = misc2c.wxMAILCAP_NETSCAPE
wxMAILCAP_KDE = misc2c.wxMAILCAP_KDE
wxMAILCAP_GNOME = misc2c.wxMAILCAP_GNOME
wxMAILCAP_ALL = misc2c.wxMAILCAP_ALL
cvar = misc2c.cvar
wxTheMimeTypesManager = wxMimeTypesManagerPtr(misc2c.cvar.wxTheMimeTypesManager)



# This file was created automatically by SWIG.
import printfwc

from misc import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from cmndlgs import *

from events import *

from frames import *

from stattool import *

from controls import *
import wx
class wxPrintDataPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=printfwc.delete_wxPrintData):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetNoCopies(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetNoCopies,(self,) + _args, _kwargs)
        return val
    def GetCollate(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetCollate,(self,) + _args, _kwargs)
        return val
    def GetOrientation(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetOrientation,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_Ok,(self,) + _args, _kwargs)
        return val
    def GetPrinterName(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPrinterName,(self,) + _args, _kwargs)
        return val
    def GetColour(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetColour,(self,) + _args, _kwargs)
        return val
    def GetDuplex(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetDuplex,(self,) + _args, _kwargs)
        return val
    def GetPaperId(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPaperId,(self,) + _args, _kwargs)
        return val
    def GetPaperSize(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPaperSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) 
        return val
    def GetQuality(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetQuality,(self,) + _args, _kwargs)
        return val
    def SetNoCopies(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetNoCopies,(self,) + _args, _kwargs)
        return val
    def SetCollate(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetCollate,(self,) + _args, _kwargs)
        return val
    def SetOrientation(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetOrientation,(self,) + _args, _kwargs)
        return val
    def SetPrinterName(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrinterName,(self,) + _args, _kwargs)
        return val
    def SetColour(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetColour,(self,) + _args, _kwargs)
        return val
    def SetDuplex(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetDuplex,(self,) + _args, _kwargs)
        return val
    def SetPaperId(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPaperId,(self,) + _args, _kwargs)
        return val
    def SetPaperSize(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPaperSize,(self,) + _args, _kwargs)
        return val
    def SetQuality(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetQuality,(self,) + _args, _kwargs)
        return val
    def GetPrinterCommand(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPrinterCommand,(self,) + _args, _kwargs)
        return val
    def GetPrinterOptions(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPrinterOptions,(self,) + _args, _kwargs)
        return val
    def GetPreviewCommand(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPreviewCommand,(self,) + _args, _kwargs)
        return val
    def GetFilename(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetFilename,(self,) + _args, _kwargs)
        return val
    def GetFontMetricPath(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetFontMetricPath,(self,) + _args, _kwargs)
        return val
    def GetPrinterScaleX(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPrinterScaleX,(self,) + _args, _kwargs)
        return val
    def GetPrinterScaleY(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPrinterScaleY,(self,) + _args, _kwargs)
        return val
    def GetPrinterTranslateX(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPrinterTranslateX,(self,) + _args, _kwargs)
        return val
    def GetPrinterTranslateY(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPrinterTranslateY,(self,) + _args, _kwargs)
        return val
    def GetPrintMode(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_GetPrintMode,(self,) + _args, _kwargs)
        return val
    def SetPrinterCommand(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrinterCommand,(self,) + _args, _kwargs)
        return val
    def SetPrinterOptions(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrinterOptions,(self,) + _args, _kwargs)
        return val
    def SetPreviewCommand(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPreviewCommand,(self,) + _args, _kwargs)
        return val
    def SetFilename(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetFilename,(self,) + _args, _kwargs)
        return val
    def SetFontMetricPath(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetFontMetricPath,(self,) + _args, _kwargs)
        return val
    def SetPrinterScaleX(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrinterScaleX,(self,) + _args, _kwargs)
        return val
    def SetPrinterScaleY(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrinterScaleY,(self,) + _args, _kwargs)
        return val
    def SetPrinterScaling(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrinterScaling,(self,) + _args, _kwargs)
        return val
    def SetPrinterTranslateX(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrinterTranslateX,(self,) + _args, _kwargs)
        return val
    def SetPrinterTranslateY(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrinterTranslateY,(self,) + _args, _kwargs)
        return val
    def SetPrinterTranslation(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrinterTranslation,(self,) + _args, _kwargs)
        return val
    def SetPrintMode(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintData_SetPrintMode,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPrintData instance at %s>" % (self.this,)
class wxPrintData(wxPrintDataPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPrintData,_args,_kwargs)
        self.thisown = 1




class wxPostScriptDCPtr(wxDCPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPrintData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPostScriptDC_GetPrintData,(self,) + _args, _kwargs)
        if val: val = wxPrintDataPtr(val) 
        return val
    def SetPrintData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPostScriptDC_SetPrintData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPostScriptDC instance at %s>" % (self.this,)
class wxPostScriptDC(wxPostScriptDCPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPostScriptDC,_args,_kwargs)
        self.thisown = 1




class wxPageSetupDialogDataPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=printfwc.delete_wxPageSetupDialogData):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def EnableHelp(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_EnableHelp,(self,) + _args, _kwargs)
        return val
    def EnableMargins(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_EnableMargins,(self,) + _args, _kwargs)
        return val
    def EnableOrientation(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_EnableOrientation,(self,) + _args, _kwargs)
        return val
    def EnablePaper(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_EnablePaper,(self,) + _args, _kwargs)
        return val
    def EnablePrinter(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_EnablePrinter,(self,) + _args, _kwargs)
        return val
    def GetDefaultMinMargins(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetDefaultMinMargins,(self,) + _args, _kwargs)
        return val
    def GetEnableMargins(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetEnableMargins,(self,) + _args, _kwargs)
        return val
    def GetEnableOrientation(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetEnableOrientation,(self,) + _args, _kwargs)
        return val
    def GetEnablePaper(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetEnablePaper,(self,) + _args, _kwargs)
        return val
    def GetEnablePrinter(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetEnablePrinter,(self,) + _args, _kwargs)
        return val
    def GetEnableHelp(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetEnableHelp,(self,) + _args, _kwargs)
        return val
    def GetDefaultInfo(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetDefaultInfo,(self,) + _args, _kwargs)
        return val
    def GetMarginTopLeft(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetMarginTopLeft,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetMarginBottomRight(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetMarginBottomRight,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetMinMarginTopLeft(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetMinMarginTopLeft,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetMinMarginBottomRight(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetMinMarginBottomRight,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def GetPaperId(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetPaperId,(self,) + _args, _kwargs)
        return val
    def GetPaperSize(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetPaperSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetPrintData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_GetPrintData,(self,) + _args, _kwargs)
        if val: val = wxPrintDataPtr(val) ; val.thisown = 1
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_Ok,(self,) + _args, _kwargs)
        return val
    def SetDefaultInfo(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_SetDefaultInfo,(self,) + _args, _kwargs)
        return val
    def SetDefaultMinMargins(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_SetDefaultMinMargins,(self,) + _args, _kwargs)
        return val
    def SetMarginTopLeft(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_SetMarginTopLeft,(self,) + _args, _kwargs)
        return val
    def SetMarginBottomRight(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_SetMarginBottomRight,(self,) + _args, _kwargs)
        return val
    def SetMinMarginTopLeft(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_SetMinMarginTopLeft,(self,) + _args, _kwargs)
        return val
    def SetMinMarginBottomRight(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_SetMinMarginBottomRight,(self,) + _args, _kwargs)
        return val
    def SetPaperId(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_SetPaperId,(self,) + _args, _kwargs)
        return val
    def SetPaperSize(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_SetPaperSize,(self,) + _args, _kwargs)
        return val
    def SetPrintData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialogData_SetPrintData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPageSetupDialogData instance at %s>" % (self.this,)
class wxPageSetupDialogData(wxPageSetupDialogDataPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPageSetupDialogData,_args,_kwargs)
        self.thisown = 1




class wxPageSetupDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPageSetupData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialog_GetPageSetupData,(self,) + _args, _kwargs)
        if val: val = wxPageSetupDialogDataPtr(val) 
        return val
    def ShowModal(self, *_args, **_kwargs):
        val = apply(printfwc.wxPageSetupDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPageSetupDialog instance at %s>" % (self.this,)
class wxPageSetupDialog(wxPageSetupDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPageSetupDialog,_args,_kwargs)
        self.thisown = 1
        #wx._StdDialogCallbacks(self)




class wxPrintDialogDataPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=printfwc.delete_wxPrintDialogData):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def EnableHelp(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_EnableHelp,(self,) + _args, _kwargs)
        return val
    def EnablePageNumbers(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_EnablePageNumbers,(self,) + _args, _kwargs)
        return val
    def EnablePrintToFile(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_EnablePrintToFile,(self,) + _args, _kwargs)
        return val
    def EnableSelection(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_EnableSelection,(self,) + _args, _kwargs)
        return val
    def GetAllPages(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_GetAllPages,(self,) + _args, _kwargs)
        return val
    def GetCollate(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_GetCollate,(self,) + _args, _kwargs)
        return val
    def GetFromPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_GetFromPage,(self,) + _args, _kwargs)
        return val
    def GetMaxPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_GetMaxPage,(self,) + _args, _kwargs)
        return val
    def GetMinPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_GetMinPage,(self,) + _args, _kwargs)
        return val
    def GetNoCopies(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_GetNoCopies,(self,) + _args, _kwargs)
        return val
    def GetPrintData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_GetPrintData,(self,) + _args, _kwargs)
        if val: val = wxPrintDataPtr(val) ; val.thisown = 1
        return val
    def GetPrintToFile(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_GetPrintToFile,(self,) + _args, _kwargs)
        return val
    def GetToPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_GetToPage,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_Ok,(self,) + _args, _kwargs)
        return val
    def SetCollate(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_SetCollate,(self,) + _args, _kwargs)
        return val
    def SetFromPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_SetFromPage,(self,) + _args, _kwargs)
        return val
    def SetMaxPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_SetMaxPage,(self,) + _args, _kwargs)
        return val
    def SetMinPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_SetMinPage,(self,) + _args, _kwargs)
        return val
    def SetNoCopies(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_SetNoCopies,(self,) + _args, _kwargs)
        return val
    def SetPrintData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_SetPrintData,(self,) + _args, _kwargs)
        return val
    def SetPrintToFile(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_SetPrintToFile,(self,) + _args, _kwargs)
        return val
    def SetSetupDialog(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_SetSetupDialog,(self,) + _args, _kwargs)
        return val
    def SetToPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialogData_SetToPage,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPrintDialogData instance at %s>" % (self.this,)
class wxPrintDialogData(wxPrintDialogDataPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPrintDialogData,_args,_kwargs)
        self.thisown = 1




class wxPrintDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPrintDialogData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialog_GetPrintDialogData,(self,) + _args, _kwargs)
        if val: val = wxPrintDialogDataPtr(val) 
        return val
    def GetPrintDC(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialog_GetPrintDC,(self,) + _args, _kwargs)
        return val
    def ShowModal(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPrintDialog instance at %s>" % (self.this,)
class wxPrintDialog(wxPrintDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPrintDialog,_args,_kwargs)
        self.thisown = 1
        #wx._StdDialogCallbacks(self)




class wxPrintoutPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def Destroy(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_Destroy,(self,) + _args, _kwargs)
        return val
    def GetDC(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_GetDC,(self,) + _args, _kwargs)
        return val
    def GetPageSizeMM(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_GetPageSizeMM,(self,) + _args, _kwargs)
        return val
    def GetPageSizePixels(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_GetPageSizePixels,(self,) + _args, _kwargs)
        return val
    def GetPPIPrinter(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_GetPPIPrinter,(self,) + _args, _kwargs)
        return val
    def GetPPIScreen(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_GetPPIScreen,(self,) + _args, _kwargs)
        return val
    def IsPreview(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_IsPreview,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDocument(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_base_OnBeginDocument,(self,) + _args, _kwargs)
        return val
    def base_OnEndDocument(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_base_OnEndDocument,(self,) + _args, _kwargs)
        return val
    def base_OnBeginPrinting(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_base_OnBeginPrinting,(self,) + _args, _kwargs)
        return val
    def base_OnEndPrinting(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_base_OnEndPrinting,(self,) + _args, _kwargs)
        return val
    def base_OnPreparePrinting(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_base_OnPreparePrinting,(self,) + _args, _kwargs)
        return val
    def base_GetPageInfo(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_base_GetPageInfo,(self,) + _args, _kwargs)
        return val
    def base_HasPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintout_base_HasPage,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPrintout instance at %s>" % (self.this,)
class wxPrintout(wxPrintoutPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPrintout,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPrintout)




class wxPrinterPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=printfwc.delete_wxPrinter):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def CreateAbortWindow(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrinter_CreateAbortWindow,(self,) + _args, _kwargs)
        return val
    def GetPrintDialogData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrinter_GetPrintDialogData,(self,) + _args, _kwargs)
        if val: val = wxPrintDialogDataPtr(val) 
        return val
    def Print(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrinter_Print,(self,) + _args, _kwargs)
        return val
    def PrintDialog(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrinter_PrintDialog,(self,) + _args, _kwargs)
        return val
    def ReportError(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrinter_ReportError,(self,) + _args, _kwargs)
        return val
    def Setup(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrinter_Setup,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPrinter instance at %s>" % (self.this,)
class wxPrinter(wxPrinterPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPrinter,_args,_kwargs)
        self.thisown = 1




class wxPrintPreviewPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetCanvas(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_GetCanvas,(self,) + _args, _kwargs)
        return val
    def GetCurrentPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_GetCurrentPage,(self,) + _args, _kwargs)
        return val
    def GetFrame(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_GetFrame,(self,) + _args, _kwargs)
        return val
    def GetMaxPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_GetMaxPage,(self,) + _args, _kwargs)
        return val
    def GetMinPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_GetMinPage,(self,) + _args, _kwargs)
        return val
    def GetPrintDialogData(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_GetPrintDialogData,(self,) + _args, _kwargs)
        if val: val = wxPrintDialogDataPtr(val) 
        return val
    def GetPrintout(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_GetPrintout,(self,) + _args, _kwargs)
        return val
    def GetPrintoutForPrinting(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_GetPrintoutForPrinting,(self,) + _args, _kwargs)
        return val
    def GetZoom(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_GetZoom,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_Ok,(self,) + _args, _kwargs)
        return val
    def Print(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_Print,(self,) + _args, _kwargs)
        return val
    def SetCanvas(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_SetCanvas,(self,) + _args, _kwargs)
        return val
    def SetCurrentPage(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_SetCurrentPage,(self,) + _args, _kwargs)
        return val
    def SetFrame(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_SetFrame,(self,) + _args, _kwargs)
        return val
    def SetPrintout(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_SetPrintout,(self,) + _args, _kwargs)
        return val
    def SetZoom(self, *_args, **_kwargs):
        val = apply(printfwc.wxPrintPreview_SetZoom,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPrintPreview instance at %s>" % (self.this,)
class wxPrintPreview(wxPrintPreviewPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPrintPreview,_args,_kwargs)
        self.thisown = 1




class wxPreviewFramePtr(wxFramePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Initialize(self, *_args, **_kwargs):
        val = apply(printfwc.wxPreviewFrame_Initialize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPreviewFrame instance at %s>" % (self.this,)
class wxPreviewFrame(wxPreviewFramePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(printfwc.new_wxPreviewFrame,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)






#-------------- FUNCTION WRAPPERS ------------------

wxPostScriptDC_SetResolution = printfwc.wxPostScriptDC_SetResolution

wxPostScriptDC_GetResolution = printfwc.wxPostScriptDC_GetResolution



#-------------- VARIABLE WRAPPERS ------------------




# This file was created automatically by SWIG.
import oglc

from misc import *

from misc2 import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

from mdi import *

from frames import *

from stattool import *

from controls import *

from controls2 import *

from windows2 import *

from cmndlgs import *

from windows3 import *

from image import *

from printfw import *

from sizers import *

from filesys import *

from oglbasic import *

from oglshapes import *

from oglshapes2 import *

from oglcanvas import *
import wx


#-------------- FUNCTION WRAPPERS ------------------

wxOGLInitialize = oglc.wxOGLInitialize

wxOGLCleanUp = oglc.wxOGLCleanUp



#-------------- VARIABLE WRAPPERS ------------------

KEY_SHIFT = oglc.KEY_SHIFT
KEY_CTRL = oglc.KEY_CTRL
ARROW_NONE = oglc.ARROW_NONE
ARROW_END = oglc.ARROW_END
ARROW_BOTH = oglc.ARROW_BOTH
ARROW_MIDDLE = oglc.ARROW_MIDDLE
ARROW_START = oglc.ARROW_START
ARROW_HOLLOW_CIRCLE = oglc.ARROW_HOLLOW_CIRCLE
ARROW_FILLED_CIRCLE = oglc.ARROW_FILLED_CIRCLE
ARROW_ARROW = oglc.ARROW_ARROW
ARROW_SINGLE_OBLIQUE = oglc.ARROW_SINGLE_OBLIQUE
ARROW_DOUBLE_OBLIQUE = oglc.ARROW_DOUBLE_OBLIQUE
ARROW_METAFILE = oglc.ARROW_METAFILE
ARROW_POSITION_END = oglc.ARROW_POSITION_END
ARROW_POSITION_START = oglc.ARROW_POSITION_START
CONTROL_POINT_VERTICAL = oglc.CONTROL_POINT_VERTICAL
CONTROL_POINT_HORIZONTAL = oglc.CONTROL_POINT_HORIZONTAL
CONTROL_POINT_DIAGONAL = oglc.CONTROL_POINT_DIAGONAL
CONTROL_POINT_ENDPOINT_TO = oglc.CONTROL_POINT_ENDPOINT_TO
CONTROL_POINT_ENDPOINT_FROM = oglc.CONTROL_POINT_ENDPOINT_FROM
CONTROL_POINT_LINE = oglc.CONTROL_POINT_LINE
FORMAT_NONE = oglc.FORMAT_NONE
FORMAT_CENTRE_HORIZ = oglc.FORMAT_CENTRE_HORIZ
FORMAT_CENTRE_VERT = oglc.FORMAT_CENTRE_VERT
FORMAT_SIZE_TO_CONTENTS = oglc.FORMAT_SIZE_TO_CONTENTS
LINE_ALIGNMENT_HORIZ = oglc.LINE_ALIGNMENT_HORIZ
LINE_ALIGNMENT_VERT = oglc.LINE_ALIGNMENT_VERT
LINE_ALIGNMENT_TO_NEXT_HANDLE = oglc.LINE_ALIGNMENT_TO_NEXT_HANDLE
LINE_ALIGNMENT_NONE = oglc.LINE_ALIGNMENT_NONE
SHADOW_NONE = oglc.SHADOW_NONE
SHADOW_LEFT = oglc.SHADOW_LEFT
SHADOW_RIGHT = oglc.SHADOW_RIGHT
OP_CLICK_LEFT = oglc.OP_CLICK_LEFT
OP_CLICK_RIGHT = oglc.OP_CLICK_RIGHT
OP_DRAG_LEFT = oglc.OP_DRAG_LEFT
OP_DRAG_RIGHT = oglc.OP_DRAG_RIGHT
OP_ALL = oglc.OP_ALL
ATTACHMENT_MODE_NONE = oglc.ATTACHMENT_MODE_NONE
ATTACHMENT_MODE_EDGE = oglc.ATTACHMENT_MODE_EDGE
ATTACHMENT_MODE_BRANCHING = oglc.ATTACHMENT_MODE_BRANCHING
BRANCHING_ATTACHMENT_NORMAL = oglc.BRANCHING_ATTACHMENT_NORMAL
BRANCHING_ATTACHMENT_BLOB = oglc.BRANCHING_ATTACHMENT_BLOB
gyCONSTRAINT_CENTRED_VERTICALLY = oglc.gyCONSTRAINT_CENTRED_VERTICALLY
gyCONSTRAINT_CENTRED_HORIZONTALLY = oglc.gyCONSTRAINT_CENTRED_HORIZONTALLY
gyCONSTRAINT_CENTRED_BOTH = oglc.gyCONSTRAINT_CENTRED_BOTH
gyCONSTRAINT_LEFT_OF = oglc.gyCONSTRAINT_LEFT_OF
gyCONSTRAINT_RIGHT_OF = oglc.gyCONSTRAINT_RIGHT_OF
gyCONSTRAINT_ABOVE = oglc.gyCONSTRAINT_ABOVE
gyCONSTRAINT_BELOW = oglc.gyCONSTRAINT_BELOW
gyCONSTRAINT_ALIGNED_TOP = oglc.gyCONSTRAINT_ALIGNED_TOP
gyCONSTRAINT_ALIGNED_BOTTOM = oglc.gyCONSTRAINT_ALIGNED_BOTTOM
gyCONSTRAINT_ALIGNED_LEFT = oglc.gyCONSTRAINT_ALIGNED_LEFT
gyCONSTRAINT_ALIGNED_RIGHT = oglc.gyCONSTRAINT_ALIGNED_RIGHT
gyCONSTRAINT_MIDALIGNED_TOP = oglc.gyCONSTRAINT_MIDALIGNED_TOP
gyCONSTRAINT_MIDALIGNED_BOTTOM = oglc.gyCONSTRAINT_MIDALIGNED_BOTTOM
gyCONSTRAINT_MIDALIGNED_LEFT = oglc.gyCONSTRAINT_MIDALIGNED_LEFT
gyCONSTRAINT_MIDALIGNED_RIGHT = oglc.gyCONSTRAINT_MIDALIGNED_RIGHT
DIVISION_SIDE_NONE = oglc.DIVISION_SIDE_NONE
DIVISION_SIDE_LEFT = oglc.DIVISION_SIDE_LEFT
DIVISION_SIDE_TOP = oglc.DIVISION_SIDE_TOP
DIVISION_SIDE_RIGHT = oglc.DIVISION_SIDE_RIGHT
DIVISION_SIDE_BOTTOM = oglc.DIVISION_SIDE_BOTTOM


#-------------- USER INCLUDE -----------------------


# aliases
wxShapeCanvas =       wxPyShapeCanvas
wxShapeEvtHandler =   wxPyShapeEvtHandler
wxShape =             wxPyShape
wxRectangleShape =    wxPyRectangleShape
wxBitmapShape =       wxPyBitmapShape
wxDrawnShape =        wxPyDrawnShape
wxCompositeShape =    wxPyCompositeShape
wxDividedShape =      wxPyDividedShape
wxDivisionShape =     wxPyDivisionShape
wxEllipseShape =      wxPyEllipseShape
wxCircleShape =       wxPyCircleShape
wxLineShape =         wxPyLineShape
wxPolygonShape =      wxPyPolygonShape
wxTextShape =         wxPyTextShape
wxControlPoint =      wxPyControlPoint

# Stuff these names into the wx namespace so wxPyConstructObject can find them
import wx
wx.wxArrowHeadPtr         = wxArrowHeadPtr
wx.wxControlPointPtr      = wxPyControlPointPtr
wx.wxDiagramPtr           = wxDiagramPtr
wx.wxOGLConstraintPtr     = wxOGLConstraintPtr
wx.wxPseudoMetaFilePtr    = wxPseudoMetaFile
wx.wxPyBitmapShapePtr     = wxPyBitmapShapePtr
wx.wxPyCircleShapePtr     = wxPyCircleShapePtr
wx.wxPyCompositeShapePtr  = wxPyCompositeShapePtr
wx.wxPyControlPointPtr    = wxPyControlPointPtr
wx.wxPyDividedShapePtr    = wxPyDividedShapePtr
wx.wxPyDivisionShapePtr   = wxPyDivisionShapePtr
wx.wxPyDrawnShapePtr      = wxPyDrawnShapePtr
wx.wxPyEllipseShapePtr    = wxPyEllipseShapePtr
wx.wxPyLineShapePtr       = wxPyLineShapePtr
wx.wxPyPolygonShapePtr    = wxPyPolygonShapePtr
wx.wxPyRectangleShapePtr  = wxPyRectangleShapePtr
wx.wxPyShapeCanvasPtr     = wxPyShapeCanvasPtr
wx.wxPyShapeEvtHandlerPtr = wxPyShapeEvtHandlerPtr
wx.wxPyShapePtr           = wxPyShapePtr
wx.wxPyTextShapePtr       = wxPyTextShapePtr
wx.wxShapeRegionPtr       = wxShapeRegionPtr



# This file was created automatically by SWIG.
import filesysc

from utils import *

from image import *

from misc import *

from gdi import *

from fonts import *

from streams import *
import wx

import types
def wxMemoryFSHandler_AddFile(filename, a, b=''):
    if wx.wxPy_isinstance(a, (wxImage, wxImagePtr)):
        __wxMemoryFSHandler_AddFile_wxImage(filename, a, b)
    elif wx.wxPy_isinstance(a, (wxBitmap, wxBitmapPtr)):
        __wxMemoryFSHandler_AddFile_wxBitmap(filename, a, b)
    elif type(a) == types.StringType:
        #__wxMemoryFSHandler_AddFile_wxString(filename, a)
        __wxMemoryFSHandler_AddFile_Data(filename, a)
    else: raise TypeError, 'wxImage, wxBitmap or string expected'

class wxFSFilePtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetStream(self, *_args, **_kwargs):
        val = apply(filesysc.wxFSFile_GetStream,(self,) + _args, _kwargs)
        return val
    def GetMimeType(self, *_args, **_kwargs):
        val = apply(filesysc.wxFSFile_GetMimeType,(self,) + _args, _kwargs)
        return val
    def GetLocation(self, *_args, **_kwargs):
        val = apply(filesysc.wxFSFile_GetLocation,(self,) + _args, _kwargs)
        return val
    def GetAnchor(self, *_args, **_kwargs):
        val = apply(filesysc.wxFSFile_GetAnchor,(self,) + _args, _kwargs)
        return val
    def GetModificationTime(self, *_args, **_kwargs):
        val = apply(filesysc.wxFSFile_GetModificationTime,(self,) + _args, _kwargs)
        if val: val = wxDateTimePtr(val) ; val.thisown = 1
        return val
    def __repr__(self):
        return "<C wxFSFile instance at %s>" % (self.this,)
class wxFSFile(wxFSFilePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(filesysc.new_wxFSFile,_args,_kwargs)
        self.thisown = 1




class wxCPPFileSystemHandlerPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxCPPFileSystemHandler instance at %s>" % (self.this,)
class wxCPPFileSystemHandler(wxCPPFileSystemHandlerPtr):
    def __init__(self,this):
        self.this = this




class wxFileSystemHandlerPtr(wxCPPFileSystemHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def CanOpen(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler_CanOpen,(self,) + _args, _kwargs)
        return val
    def OpenFile(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler_OpenFile,(self,) + _args, _kwargs)
        return val
    def FindFirst(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler_FindFirst,(self,) + _args, _kwargs)
        return val
    def FindNext(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler_FindNext,(self,) + _args, _kwargs)
        return val
    def GetProtocol(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler_GetProtocol,(self,) + _args, _kwargs)
        return val
    def GetLeftLocation(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler_GetLeftLocation,(self,) + _args, _kwargs)
        return val
    def GetAnchor(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler_GetAnchor,(self,) + _args, _kwargs)
        return val
    def GetRightLocation(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler_GetRightLocation,(self,) + _args, _kwargs)
        return val
    def GetMimeTypeFromExt(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystemHandler_GetMimeTypeFromExt,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFileSystemHandler instance at %s>" % (self.this,)
class wxFileSystemHandler(wxFileSystemHandlerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(filesysc.new_wxFileSystemHandler,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxFileSystemHandler)




class wxFileSystemPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def ChangePathTo(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystem_ChangePathTo,(self,) + _args, _kwargs)
        return val
    def GetPath(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystem_GetPath,(self,) + _args, _kwargs)
        return val
    def OpenFile(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystem_OpenFile,(self,) + _args, _kwargs)
        return val
    def FindFirst(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystem_FindFirst,(self,) + _args, _kwargs)
        return val
    def FindNext(self, *_args, **_kwargs):
        val = apply(filesysc.wxFileSystem_FindNext,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFileSystem instance at %s>" % (self.this,)
class wxFileSystem(wxFileSystemPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(filesysc.new_wxFileSystem,_args,_kwargs)
        self.thisown = 1




class wxInternetFSHandlerPtr(wxCPPFileSystemHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def CanOpen(self, *_args, **_kwargs):
        val = apply(filesysc.wxInternetFSHandler_CanOpen,(self,) + _args, _kwargs)
        return val
    def OpenFile(self, *_args, **_kwargs):
        val = apply(filesysc.wxInternetFSHandler_OpenFile,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxInternetFSHandler instance at %s>" % (self.this,)
class wxInternetFSHandler(wxInternetFSHandlerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(filesysc.new_wxInternetFSHandler,_args,_kwargs)
        self.thisown = 1




class wxZipFSHandlerPtr(wxCPPFileSystemHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def CanOpen(self, *_args, **_kwargs):
        val = apply(filesysc.wxZipFSHandler_CanOpen,(self,) + _args, _kwargs)
        return val
    def OpenFile(self, *_args, **_kwargs):
        val = apply(filesysc.wxZipFSHandler_OpenFile,(self,) + _args, _kwargs)
        return val
    def FindFirst(self, *_args, **_kwargs):
        val = apply(filesysc.wxZipFSHandler_FindFirst,(self,) + _args, _kwargs)
        return val
    def FindNext(self, *_args, **_kwargs):
        val = apply(filesysc.wxZipFSHandler_FindNext,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxZipFSHandler instance at %s>" % (self.this,)
class wxZipFSHandler(wxZipFSHandlerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(filesysc.new_wxZipFSHandler,_args,_kwargs)
        self.thisown = 1




class wxMemoryFSHandlerPtr(wxCPPFileSystemHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def CanOpen(self, *_args, **_kwargs):
        val = apply(filesysc.wxMemoryFSHandler_CanOpen,(self,) + _args, _kwargs)
        return val
    def OpenFile(self, *_args, **_kwargs):
        val = apply(filesysc.wxMemoryFSHandler_OpenFile,(self,) + _args, _kwargs)
        return val
    def FindFirst(self, *_args, **_kwargs):
        val = apply(filesysc.wxMemoryFSHandler_FindFirst,(self,) + _args, _kwargs)
        return val
    def FindNext(self, *_args, **_kwargs):
        val = apply(filesysc.wxMemoryFSHandler_FindNext,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMemoryFSHandler instance at %s>" % (self.this,)
class wxMemoryFSHandler(wxMemoryFSHandlerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(filesysc.new_wxMemoryFSHandler,_args,_kwargs)
        self.thisown = 1






#-------------- FUNCTION WRAPPERS ------------------

__wxMemoryFSHandler_AddFile_wxImage = filesysc.__wxMemoryFSHandler_AddFile_wxImage

__wxMemoryFSHandler_AddFile_wxBitmap = filesysc.__wxMemoryFSHandler_AddFile_wxBitmap

__wxMemoryFSHandler_AddFile_Data = filesysc.__wxMemoryFSHandler_AddFile_Data

wxFileSystem_AddHandler = filesysc.wxFileSystem_AddHandler

wxFileSystem_CleanUpHandlers = filesysc.wxFileSystem_CleanUpHandlers

wxMemoryFSHandler_RemoveFile = filesysc.wxMemoryFSHandler_RemoveFile



#-------------- VARIABLE WRAPPERS ------------------

